/// Use this class as an annotation for describing how specific fields should
/// be treated by the code generator
class CloneKey {
  /// If true the field will not be taken into account when cloning
  /// Default: false
  final bool ignore;

  /// If true then cloning will use currentData.field even if null
  /// Default: false
  final bool forceCurrentData;

  /// If true then cloning will use newData.field even if null
  /// Default: false
  final bool forceNewData;

  /// Indicates that an empty List, Set, Map or Iterable to be considered
  /// as a null value when deciding to clone from newData or keep currentData.
  /// Default: true
  final bool considerEmptyCollectionAsNull;

  /// The value to use if the currentData or newData is `null`.
  final Object? defaultValue;

  /// A [Function] to use when clone the annotated field.
  ///
  /// Must be a top-level or static [Function] with two positional parameters
  /// compatible with the field being cloned that returns the same type as the cloned field.
  /// e.g: Type? function({Type? currentData, Type newData})
  final Function? cloneFunction;

  const CloneKey({
    bool? ignore,
    bool? forceCurrentData,
    bool? forceNewData,
    bool? considerEmptyCollectionAsNull,
    this.defaultValue,
    this.cloneFunction,
  })  : ignore = ignore ?? false,
        forceCurrentData = forceCurrentData ?? false,
        forceNewData = forceNewData ?? false,
        considerEmptyCollectionAsNull = considerEmptyCollectionAsNull ?? true;
}
