/// Use this class as an annotation for describing how specific fields should
/// be treated by the diff generator
class DiffKey {
  /// If true the field will not be taken into account when checking if it's
  /// different, so this means the result diff object will have this field null.
  /// Default: false
  final bool ignore;

  /// If true then diff function will use currentData.field even if null
  /// Default: false
  final bool forceCurrentData;

  /// If true then diff function will use newData.field even if null
  /// Default: false
  final bool forceNewData;

  /// The value to use if currentData and newData are equal.
  final Object? defaultValue;

  /// A [Function] to use when diff the annotated field.
  ///
  /// Must be a top-level or static [Function] with two positional parameters
  /// compatible with the field being diffed that returns the same type as the diffed field.
  /// e.g: Type? function({Type? currentData, Type newData})
  final Function? diffFunction;

  const DiffKey({
    bool? ignore,
    bool? forceCurrentData,
    bool? forceNewData,
    this.defaultValue,
    this.diffFunction,
  })  : ignore = ignore ?? false,
        forceCurrentData = forceCurrentData ?? false,
        forceNewData = forceNewData ?? false;
}
